@@ -35,6 +35,7 @@ from forgeimporters.base import (
         )
 from forgeimporters.google import GoogleCodeProjectExtractor
 from forgeimporters.google import GoogleCodeProjectNameValidator
+from forgeimporters.google import split_project_name
 
 TARGET_APP_ENTRY_POINT_NAME = 'Wiki'
 DATE_FORMAT = '%a %b %d %H:%M:%S %Y'
@@ -127,25 +128,29 @@ class GoogleCodeWikiPage(object):
         return re.sub(pat, repl, text)
 
     def rewrite_issue_links(self, text):
-        pat = r'\[([^\]]+)\]\(/p/([^/]+)/issues/detail\?id=([^\)]+)\)'
+        pat = r'\[([^\]]+)\]\((/a/[^/]+)?/p/([^/]+)/issues/detail\?id=([^\)]+)\)'
         def repl(match):
-            text, project, issue = match.groups()
-            if project == self.project_name:
+            text, hosted_domain_prefix, project, issue = match.groups()
+            if hosted_domain_prefix is None:
+                hosted_domain_prefix = ''
+            if (hosted_domain_prefix, project) == split_project_name(self.project_name):
                 repl_pat = u'[{text}](#{issue})'
             else:
-                repl_pat = u'[{text}](https://code.google.com/p/{project}/issues/detail?id={issue})'
-            return repl_pat.format(text=text, project=project, issue=issue)
+                repl_pat = u'[{text}](https://code.google.com{hosted_domain_prefix}/p/{project}/issues/detail?id={issue})'
+            return repl_pat.format(text=text, project=project, issue=issue, hosted_domain_prefix=hosted_domain_prefix)
         return re.sub(pat, repl, text)
 
     def rewrite_source_links(self, text):
-        pat = r'\[([^\]]+)\]\(/p/([^/]+)/source/detail\?r=([^\)]+)\)'
+        pat = r'\[([^\]]+)\]\((/a/[^/]+)?/p/([^/]+)/source/detail\?r=([^\)]+)\)'
         def repl(match):
-            text, project, rev = match.groups()
-            if project == self.project_name:
+            text, hosted_domain_prefix, project, rev = match.groups()
+            if hosted_domain_prefix is None:
+                hosted_domain_prefix = ''
+            if (hosted_domain_prefix, project) == split_project_name(self.project_name):
                 repl_pat = u'[r{rev}]'
             else:
-                repl_pat = u'[{text}](https://code.google.com/p/{project}/source/detail?r={rev})'
-            return repl_pat.format(text=text, project=project, rev=rev)
+                repl_pat = u'[{text}](https://code.google.com{hosted_domain_prefix}/p/{project}/source/detail?r={rev})'
+            return repl_pat.format(text=text, project=project, rev=rev, hosted_domain_prefix=hosted_domain_prefix)
         return re.sub(pat, repl, text)
 
     @LazyProperty
@@ -183,12 +188,16 @@ class GoogleCodeWikiPage(object):
 class GoogleCodeWikiExtractor(GoogleCodeProjectExtractor):
     PAGE_MAP = GoogleCodeProjectExtractor.PAGE_MAP
     PAGE_MAP.update({
-        'wiki_index': GoogleCodeProjectExtractor.BASE_URL + '/p/{project_name}/w/list',
+        'wiki_index': GoogleCodeProjectExtractor.BASE_URL + '{hosted_domain_prefix}/p/{project_name}/w/list',
         })
 
     def get_wiki_pages(self):
         page = self.get_page('wiki_index')
-        RE_WIKI_PAGE_URL = r'^/p/{0}/wiki/.*$'.format(self.project_name)
+        hosted_domain_prefix, project_name = split_project_name(self.project_name)
+        RE_WIKI_PAGE_URL = r'^{hosted_domain_prefix}/p/{project_name}/wiki/.*$'.format(
+                hosted_domain_prefix=hosted_domain_prefix,
+                project_name=project_name,
+        )
         seen = set()
         for a in page.find(id="resultstable").findAll("a"):
             if re.match(RE_WIKI_PAGE_URL, a['href']) and a['href'] not in seen:
