@@ -92,6 +92,8 @@ class TestGoogleCodeWikiComment(TestCase):
 
 
 class TestGoogleCodeWikiPage(TestCase):
+    maxDiff = None
+
     HTML = '''
     <div id="maincol">
       <div id="wikipage">
@@ -147,10 +149,10 @@ class TestGoogleCodeWikiPage(TestCase):
     </div>
     '''
 
-    def _makeOne(self):
+    def _makeOne(self, html=HTML, project_name='myproject', url='http://code.google.com/p/myproject/wiki/MyPage'):
         with patch('googlecodewikiimporter.importer.urllib2.urlopen') as urlopen:
-            urlopen.return_value = self.HTML
-            return GoogleCodeWikiPage('MyPage', 'http://code.google.com/p/myproject/wiki/MyPage', 'myproject')
+            urlopen.return_value = html
+            return GoogleCodeWikiPage('MyPage', url, project_name)
 
     def test_rewrite_wiki_links(self):
         s = '[Page One](/p/myproject/wiki/PageOne) [External](http://example.com)'
@@ -173,6 +175,53 @@ Inter-project issue link: [issue 1](https://code.google.com/p/otherproject/issue
 Intra-project source link: [r1]  
 Inter-project source link: [r1](https://code.google.com/p/otherproject/source/detail?r=1)''')
 
+    def test_ref_links_hosted_domain(self):
+        html = '''
+        <div id="maincol">
+          <div id="wikipage">
+            <table>
+              <tbody><tr>
+                <td style="vertical-align:top; padding-left:5px">
+                  <div id="wikiheader">
+                    <span style="font-size:120%;font-weight:bold">MyPage</span>
+                    <div>
+                      <i>Page description</i>
+                      <br>
+                      <a class="label" href="/p/mypage/w/list?q=label:MyLabel" title="MyLabel">MyLabel</a>
+                      <div id="wikiauthor">
+                        Updated <span title="Sat Jul 6 06:40:08 2013">Jul 6, 2013</span>
+                        by <a class="userlink" href="/u/testauthor/">testauthor</a>
+                      </div>
+                    </div>
+                  </div>
+                  <div id="wikicontent">
+                    <div class="vt" id="wikimaincol">
+                      Intra-project issue link: <a href="/a/eclipselabs.org/p/myproject/issues/detail?id=1">issue 1</a><br/>
+                      Inter-project issue link: <a href="/a/eclipselabs.org/p/otherproject/issues/detail?id=1">issue 1</a><br/>
+                      Intra-project source link: <a href="/a/eclipselabs.org/p/myproject/source/detail?r=1">r1</a><br/>
+                      Inter-project source link: <a href="/a/eclipselabs.org/p/otherproject/source/detail?r=1">r1</a><br/>
+                    </div>
+                  </div>
+                </td></tr>
+              <tr></tr>
+              </tbody>
+            </table>
+          </div>
+          <div id="wikicommentcol">
+            <div class="collapse">
+              <div id="commentlist">
+              </div>
+            </div>
+          </div>
+        </div>
+        '''
+        p = self._makeOne(html, 'a/eclipselabs.org/p/myproject', url='http://code.google.com/a/eclipselabs.org/p/myproject/wiki/MyPage')
+        self.assertEqual(p.text.strip(), u'''\
+Intra-project issue link: [issue 1](#1)  
+Inter-project issue link: [issue 1](https://code.google.com/a/eclipselabs.org/p/otherproject/issues/detail?id=1)  
+Intra-project source link: [r1]  
+Inter-project source link: [r1](https://code.google.com/a/eclipselabs.org/p/otherproject/source/detail?r=1)''')
+
     def test_timestamp(self):
         from datetime import datetime
         p = self._makeOne()
@@ -329,9 +378,9 @@ class TestGoogleCodeWikiImportController(TestController, TestCase):
 
 class TestGoogleCodeWikiExtractor(TestCase):
 
-    def _make_extractor(self, html, url='http://code.google.com/p/my-project/w/list'):
+    def _make_extractor(self, html, url='http://code.google.com/p/my-project/w/list', project_name='my-project'):
         from BeautifulSoup import BeautifulSoup
-        extractor = GoogleCodeWikiExtractor('my-project')
+        extractor = GoogleCodeWikiExtractor(project_name)
         extractor._page_cache = {url: BeautifulSoup(html)}
         return extractor
 
@@ -344,6 +393,18 @@ class TestGoogleCodeWikiExtractor(TestCase):
         self.assertEqual(list(extractor.get_wiki_pages()), [
             ('PageOne', 'http://code.google.com/p/my-project/wiki/PageOne')])
 
+    def test_get_wiki_pages_hosted_domain(self):
+        extractor = self._make_extractor('''
+        <div id="resultstable">
+            <a href="#">Link that's not a wiki page</a>
+            <a href="/a/eclipselabs.org/p/my-project/wiki/PageOne">PageOne</a>
+        </div>''',
+        url='http://code.google.com/a/eclipselabs.org/p/my-project/w/list',
+        project_name='a/eclipselabs.org/p/my-project',
+        )
+        self.assertEqual(list(extractor.get_wiki_pages()), [
+            ('PageOne', 'http://code.google.com/a/eclipselabs.org/p/my-project/wiki/PageOne')])
+
     def test_get_default_wiki_page_name(self):
         extractor = self._make_extractor('''
         <div id="mt">
